import type { AddressManager } from '@libp2p/interface-address-manager';
import type { ConnectionManager, Dialer } from '@libp2p/interface-connection-manager';
import type { PeerId } from '@libp2p/interface-peer-id';
import type { PeerRouting } from '@libp2p/interface-peer-routing';
import type { IncomingStreamData, Registrar } from '@libp2p/interface-registrar';
import type { TransportManager } from '@libp2p/interface-transport';
import type { Startable } from '@libp2p/interfaces/startable';
export interface AutonatServiceInit {
    /**
     * Allows overriding the protocol prefix used
     */
    protocolPrefix: string;
    /**
     * How long we should wait for a remote peer to verify our external address
     */
    timeout: number;
    /**
     * How long to wait after startup before trying to verify our external address
     */
    startupDelay: number;
    /**
     * Verify our external addresses this often
     */
    refreshInterval: number;
    /**
     * How many parallel inbound autonat streams we allow per-connection
     */
    maxInboundStreams: number;
    /**
     * How many parallel outbound autonat streams we allow per-connection
     */
    maxOutboundStreams: number;
}
export interface DefaultAutonatComponents {
    registrar: Registrar;
    addressManager: AddressManager;
    transportManager: TransportManager;
    dialer: Dialer;
    peerId: PeerId;
    connectionManager: ConnectionManager;
    peerRouting: PeerRouting;
}
export declare class AutonatService implements Startable {
    private readonly components;
    private readonly _init;
    private readonly startupDelay;
    private readonly refreshInterval;
    private verifyAddressTimeout?;
    private started;
    constructor(components: DefaultAutonatComponents, init: AutonatServiceInit);
    isStarted(): boolean;
    start(): Promise<void>;
    stop(): Promise<void>;
    /**
     * Handle an incoming autonat request
     */
    handleIncomingAutonatStream(data: IncomingStreamData): Promise<void>;
    _verifyExternalAddresses(): void;
    /**
     * Our multicodec topology noticed a new peer that supports autonat
     */
    verifyExternalAddresses(): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map